@@ -930,9 +930,10 @@ SEXP R_pnssuperset(SEXP R_x, SEXP R_y, SEXP R_e, SEXP R_p, SEXP R_v) {
 	l = INTEGER(px)[i];
 	n = l-f;
 	if (n == 0) {
-	    if (LOGICAL(R_p)[0])
-		SET_VECTOR_ELT(r, i-1, allocVector(INTSXP, 0));
-	    else {
+	    if (LOGICAL(R_p)[0]) {
+		SET_VECTOR_ELT(r, i-1, PROTECT(allocVector(INTSXP, 0)));
+		UNPROTECT(1);
+	    } else {
 		cb[n++] = e;
 		if (db) {
 		    PN *q = db[cb[e]];
@@ -943,7 +944,8 @@ SEXP R_pnssuperset(SEXP R_x, SEXP R_y, SEXP R_e, SEXP R_p, SEXP R_v) {
 		}
 		SEXP t;
 
-		SET_VECTOR_ELT(r, i-1, (t = allocVector(INTSXP, n)));
+		SET_VECTOR_ELT(r, i-1, PROTECT(t = allocVector(INTSXP, n)));
+		UNPROTECT(1);
 		memcpy(INTEGER(t), cb, sizeof(int) * n);
 	    }
 	    continue;
@@ -980,7 +982,8 @@ SEXP R_pnssuperset(SEXP R_x, SEXP R_y, SEXP R_e, SEXP R_p, SEXP R_v) {
 	    }
 	    SEXP t;
 
-	    SET_VECTOR_ELT(r, i-1, (t = allocVector(INTSXP, cn)));
+	    SET_VECTOR_ELT(r, i-1, PROTECT(t = allocVector(INTSXP, cn)));
+	    UNPROTECT(1);
 	    memcpy(INTEGER(t), cb, sizeof(int) * cn);
 	    R_isort(INTEGER(t), cn);
 	}
